﻿Imports System.IO
Imports System.Windows.Forms
Imports YiaoWang.DataBase
Imports YiaoWang.Network
Imports YiaoWang.Utility
Imports YiaoWang.Vender.Office
Imports YiaoWang.Windows.Forms

Public Class YWUtilitySample

#Region " YWCsvConverter "

    ''' <summary>
    ''' 一覧にテスト用のダミーデータを表示します。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub btnCsvSetTable_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnCsvSetTable.Click
        Dim dt As New DataTable
        dt.Columns.Add("サンプル①")
        dt.Columns.Add("サンプル②")
        For i As Integer = 0 To 100
            dt.Rows.Add(New Object() {i, "サンプル"})
        Next
        Me.dgvCsvConversion.SetDataTable(dt)
    End Sub

    ''' <summary>
    ''' CSV形式のファイルからデータを取得します。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub btnReadCsv_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnReadCsv.Click
        If Not File.Exists(Me.txtReadCsvPath.Text) Then
            Dim msg As New YWMsg("該当するファイル存在しません。")
            msg.ShowE()
            Return
        End If
        Dim dc As New YWCsvConverter(Me.txtReadCsvPath.Text)
        Me.dgvCsvConversion.SetDataTable(dc.ReadCsv)
    End Sub

    ''' <summary>
    ''' CSV形式のファイルを出力します。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub btnWriteCsv_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnWriteCsv.Click
        Dim dt As DataTable = Me.dgvCsvConversion.GetDataTable()
        Dim dc As New YWCsvConverter(Me.txtWriteCsvPath.Text)
        dc.WriteCsv(dt, True, False)
    End Sub

    ''' <summary>
    ''' TSV形式のファイルからデータを取得します。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub btnReadTsvTable_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnReadTsvTable.Click
        If Not File.Exists(Me.txtReadTsvPath.Text) Then
            Dim msg As New YWMsg("該当するファイル存在しません。")
            msg.ShowE()
            Return
        End If
        Dim dc As New YWCsvConverter(Me.txtReadTsvPath.Text)
        Me.dgvCsvConversion.SetDataTable(dc.ReadTsv)
    End Sub

    ''' <summary>
    ''' TSV形式のファイルを出力します。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub btnWriteTsv_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnWriteTsv.Click
        Dim dt As DataTable = Me.dgvCsvConversion.GetDataTable()
        Dim dc As New YWCsvConverter(Me.txtWriteTsvPath.Text)
        dc.WriteTsv(dt, True, False)
    End Sub

#End Region

#Region " YWDataTableOperator "

    ''' <summary>
    ''' データテーブルの値を加工します。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub btnEditData_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnEditData.Click

        Me.dgvEditData.Reset()

        ' オリジナルデータ。（本当はDBから取得）
        Const Y_KEY1 As String = "Y_KEY1"
        Const Y_KEY2 As String = "Y_KEY2"
        Const X_KEY As String = "X_KEY"
        Const VALUE As String = "VALUE"

        Dim dtOriginal As New DataTable()
        dtOriginal.Columns.Add(Y_KEY1)
        dtOriginal.Columns.Add(Y_KEY2)
        dtOriginal.Columns.Add(X_KEY)
        dtOriginal.Columns.Add(VALUE)
        dtOriginal.Rows.Add(1, "あ", "C", "☆")
        dtOriginal.Rows.Add(1, "あ", "B", "")
        dtOriginal.Rows.Add(1, "あ", "A", "")
        dtOriginal.Rows.Add(2, "い", "B", "☆")
        dtOriginal.Rows.Add(2, "い", "C", "")

        If Me.rdoEditData1.Checked Then
            Me.dgvEditData.SetDataTable(dtOriginal)
            Return
        End If

        ' KEYの重複を除外したテーブルを作成。
        Dim dto1 As New YWDataTableOperator()
        dto1.DataTable = dtOriginal.Copy()
        dto1.DistinctKeyOnly(Y_KEY1, Y_KEY2)
        Dim dtResult As DataTable = dto1.DataTable
        If Me.rdoEditData2.Checked Then
            Me.dgvEditData.SetDataTable(dtResult)
            Return
        End If

        ' 横軸を展開。
        Dim dto2 As New YWDataTableOperator()
        dto2.DataTable = dtOriginal.Copy()
        dto2.DistinctKeyOnly(X_KEY)
        Dim drX() As DataRow = dto2.DataTable.Select("", X_KEY)
        For i As Integer = 0 To drX.Length - 1
            dtResult.Columns.Add(drX(i)(X_KEY).ToString(), drX(i).Table.Columns(X_KEY).DataType)
        Next

        If Me.rdoEditData3.Checked Then
            Me.dgvEditData.SetDataTable(dtResult)
            Return
        End If

        ' 値を設定
        For Each drOriginal As DataRow In dtOriginal.Rows
            Dim drY() As DataRow = dtResult.Select(SFormat("{0} = '{1}' and {2} = '{3}'", Y_KEY1, drOriginal(Y_KEY1), Y_KEY2, drOriginal(Y_KEY2)))
            drY(0)(drOriginal(X_KEY).ToString()) = drOriginal(VALUE)
        Next

        If Me.rdoEditData4.Checked Then
            Me.dgvEditData.SetDataTable(dtResult)
            Return
        End If

    End Sub

#End Region

#Region " YWDirHelper "

    ''' <summary>
    ''' フォルダダイアログを表示して、選択したパスをテキストボックスに設定します。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>YiaoWang.Windows.Forms.YWFolderDialogButton を使用しています。</remarks>
    Private Sub btnNetShareDirectory_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnNetShareDirectory.Click
        Me.txtNetShareDirectory.Text = Me.btnNetShareDirectory.SelectedPath
    End Sub

    ''' <summary>
    ''' フォルダを共有します。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub btnNetShareAdd_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnNetShareAdd.Click
        If Me.txtNetShareDirectory.IsNoValue Then Return
        Dim dir As New DirectoryInfo(Me.txtNetShareDirectory.Text)
        Try
            YWDirHelper.NetShareAdd(Nothing, dir.Name, -1, "テスト共有", dir.FullName, "")
            Dim msg As New YWMsg()
            msg.AddLN("共有しました。")
            msg.ShowI()
            Return
        Catch ex As Netapi32Exception
            Dim msg As New YWMsg()
            msg.AddLN(ex.Message)
            msg.ShowE()
            Return
        End Try
    End Sub

    ''' <summary>
    ''' フォルダの共有を解除します。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub btnNetShareDel_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnNetShareDel.Click
        If Me.txtNetShareDirectory.IsNoValue Then Return
        Dim dir As New DirectoryInfo(Me.txtNetShareDirectory.Text)
        Try
            YWDirHelper.NetShareDel(Nothing, dir.Name)
            Dim msg As New YWMsg()
            msg.AddLN("共有を解除しました。")
            msg.ShowI()
            Return
        Catch ex As Netapi32Exception
            Dim msg As New YWMsg()
            msg.AddLN(ex.Message)
            msg.ShowE()
            Return
        End Try
    End Sub

#End Region

#Region " YWProcess "

    ''' <summary>
    ''' アセンブリファイル内のフォームを表示します。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub btnShellAssemblyForm_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnShellAssemblyForm.Click
        YWProcess.ShellAssemblyForm("YiaoWangSample.exe", "YiaoWang.YiaoWangSample.Main")
    End Sub

#End Region

End Class
